﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace HierarchyNavigator_Sample
{
    /// <summary>
    /// Interaction logic for UserControl1.xaml
    /// </summary>
    public partial class UserControl1 : UserControl
    {
        public UserControl1()
        {
            InitializeComponent();
            this.DataContext = this;
            this.HierarchyItems = new ObservableCollection<HierarchyItem>();
            HierarchyItem root = new HierarchyItem("My Files");

            //Only show the initial folders in the root
            //Later implementation: Clicking on a folder creates sub-folder list as child items at runtime
            HierarchyItem item1 = new HierarchyItem("Item1");
            item1.ContentString = @"C:\Test";
            root.HierarchyItems.Add(item1);

            HierarchyItem item2 = new HierarchyItem("Item2");
            item2.ContentString = @"D:\Test";
            root.HierarchyItems.Add(item2);

            this.HierarchyItems.Add(root);
        }



        public ObservableCollection<HierarchyItem> HierarchyItems
        {
            get { return (ObservableCollection<HierarchyItem>)GetValue(HierarchyItemsProperty); }
            set { SetValue(HierarchyItemsProperty, value); }
        }

        // Using a DependencyProperty as the backing store for HierarchyItems.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty HierarchyItemsProperty =
            DependencyProperty.Register("HierarchyItems", typeof(ObservableCollection<HierarchyItem>), typeof(UserControl1), new PropertyMetadata(null));

    }

    public class HierarchicalItemsSource : ObservableCollection<HierarchyItem>
    {
        public HierarchicalItemsSource()
        {
           
            HierarchyItem root = new HierarchyItem("My Files");

            //Only show the initial folders in the root
            //Later implementation: Clicking on a folder creates sub-folder list as child items at runtime
            HierarchyItem item1 = new HierarchyItem("Item1");
            item1.ContentString = @"C:\Test";
            root.HierarchyItems.Add(item1);

            HierarchyItem item2 = new HierarchyItem("Item2");
            item2.ContentString = @"D:\Test"; 
                root.HierarchyItems.Add(item2);

            this.Add(root);
        }
    }

    public class HierarchyItem
    {
        public string ContentString { get; set; }
        public HierarchyItem(string content)
        {
            this.ContentString = content;
            itemsObservableCollection = new ObservableCollection<HierarchyItem>();
            itemsObservableCollection.CollectionChanged += ItemsObservableCollection_CollectionChanged;

            if (!Directory.Exists(content)) return;

            string[] myItems = Directory.GetDirectories(content);

            foreach (string item in myItems)
            {
                itemsObservableCollection.Add(new HierarchyItem(item));
            }
            HierarchyItems = itemsObservableCollection;
        }

        private void ItemsObservableCollection_CollectionChanged(object sender, System.Collections.Specialized.NotifyCollectionChangedEventArgs e)
        {
        }

        private ObservableCollection<HierarchyItem> itemsObservableCollection;
        public ObservableCollection<HierarchyItem> HierarchyItems
        {
            get { return itemsObservableCollection; }
            set
            {
                if (itemsObservableCollection != value)
                {
                    itemsObservableCollection = value;
                }
            }
        }
    }
   
}
